@@ -10,7 +10,7 @@ from ..web_search import search_lo_doc
 def _display_help() -> None:
     help = """Search LibreOffice API.
     Option -h, --help, Displays this help
-    Option -v, --no-verbatium, for a non verbatium search.
+    Option -v, --no-verbatim, for a non verbatim search.
     Use prefixes such as: writer, draw, impress, base, calc, chart2.
     Example:
         lodoc text module
@@ -20,6 +20,7 @@ def _display_help() -> None:
         lodoc Impress
         """
     print(help)
+    print("Other Commands, loapi, loguide, loproc")
 # endregion interal Func
 
 # region main()
@@ -36,13 +37,13 @@ def main() -> int:
     if arg1.lower() in ('-h', '--help'):
         _display_help()
         return 0
-    if arg1.lower() in ('-v', '--no-verbatium'):
-        verbatium = False
+    if arg1.lower() in ('-v', '--no-verbatim'):
+        verbatim = False
         arg1 = str(search.pop(0))
     else:
-        verbatium = True
+        verbatim = True
     arg2 = "" if search_len < 2 else search.pop(0)
     arg3 = "" if search_len < 3 else " ".join(search)
-    search_lo_doc.search(arg1=arg1, arg2=arg2, arg3=arg3, verbatium=verbatium)
+    search_lo_doc.search(arg1=arg1, arg2=arg2, arg3=arg3, verbatim=verbatim)
     return 0
 # endregion main()
